/*
* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
* Copyright (C) INRIA - Allan CORNET
* 
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at    
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

/*--------------------------------------------------------------------------*/
#ifndef __STARTUPMESSAGEBOX_H__
#define __STARTUPMESSAGEBOX_H__

#include "dynlib_scilab_windows.h"

/**
* Display startup message box
*/
SCILAB_WINDOWS_IMPEXP void StartupMessageBox(void);

#endif /* __STARTUPMESSAGEBOX_H__ */
/*--------------------------------------------------------------------------*/
